<?php

namespace Drupal\views_responsive_columns\Plugin\views\style;

use Drupal\core\form\FormStateInterface;
use Drupal\views\Plugin\views\style\StylePluginBase;

/**
 * Style plugin to render results as columns.
 *
 * @ingroup views_style_plugins
 *
 * @ViewsStyle(
 *   id = "views_responsive_columns",
 *   title = @Translation("Responsive Columns"),
 *   help = @Translation("Renders results as responsive columns."),
 *   theme = "views_view_views_responsive_columns",
 *   display_types = { "normal" }
 * )
 */
class ViewsResponsiveColumns extends StylePluginBase {

  protected $usesRowPlugin = TRUE;

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['xs'] = ['default' => [
      'column_count' => 1,
      'break_point' => 600,
    ]];

    $options['s'] = ['default' => [
      'column_count' => 2,
      'break_point' => 800,
    ]];

    $options['m'] = ['default' => [
      'column_count' => 3,
      'break_point' => 1000,
    ]];

    $options['l'] = ['default' => [
      'column_count' => 4,
      'break_point' => 1200,
    ]];

    $options['xl'] = ['default' => [
      'column_count' => 5,
      'break_point' => 1400,
    ]];

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    $form['xs'] = [
      '#type' => 'details',
      '#title' => $this->t('XS'),
    ];

    $form['xs']['column_count'] = [
      '#type' => 'number',
      '#title' => t('Column count'),
      '#default_value' => $this->options['xs']['column_count'],
    ];

    $form['xs']['break_point'] = [
      '#type' => 'number',
      '#title' => t('Break point (px)'),
      '#default_value' => $this->options['xs']['break_point'],
      '#description' => ''
    ];

    $form['s'] = [
      '#type' => 'details',
      '#title' => $this->t('S'),
    ];

    $form['s']['column_count'] = [
      '#type' => 'number',
      '#title' => t('Column count'),
      '#default_value' => $this->options['s']['column_count'],
    ];

    $form['s']['break_point'] = [
      '#type' => 'number',
      '#title' => t('Break point (px)'),
      '#default_value' => $this->options['s']['break_point'],
      '#description' => ''
    ];

    $form['m'] = [
      '#type' => 'details',
      '#title' => $this->t('M'),
    ];

    $form['m']['column_count'] = [
      '#type' => 'number',
      '#title' => t('Column count'),
      '#default_value' => $this->options['m']['column_count'],
    ];

    $form['m']['break_point'] = [
      '#type' => 'number',
      '#title' => t('Break point (px)'),
      '#default_value' => $this->options['m']['break_point'],
      '#description' => ''
    ];

    $form['l'] = [
      '#type' => 'details',
      '#title' => $this->t('L'),
    ];

    $form['l']['column_count'] = [
      '#type' => 'number',
      '#title' => t('Column count'),
      '#default_value' => $this->options['l']['column_count'],
    ];

    $form['l']['break_point'] = [
      '#type' => 'number',
      '#title' => t('Break point (px)'),
      '#default_value' => $this->options['l']['break_point'],
      '#description' => ''
    ];

    $form['xl'] = [
      '#type' => 'details',
      '#title' => $this->t('XL'),
    ];

    $form['xl']['column_count'] = [
      '#type' => 'number',
      '#title' => t('Column count'),
      '#default_value' => $this->options['xl']['column_count'],
    ];

    $form['xl']['break_point'] = [
      '#type' => 'number',
      '#title' => t('Break point (px)'),
      '#default_value' => $this->options['xl']['break_point'],
      '#description' => ''
    ];

  }

}
